# Module ddi  la conversion des entits SGML en caractres unicodes
package Entity2uni;  

# pragma ou directives de compilation

use strict;
use IO::Handle;

#------------------------------------------------------------------------------------------------
use Exporter;

our @ISA = qw(Exporter);
our @EXPORT = qw( &convertEntities); 	
our $VERSION     = '1.0'; 		


BEGIN {
}

#------------------------------------------------------------------------------------------------
# Dclarations des variables globales

# table de conversion extraite de http://www.ncbi.nlm.nih.gov/corehtml/query/static/entities.html
my %entity2uni;

$entity2uni{"&aacute;"}="00E1";
$entity2uni{"&Aacute;"}="00C1";
$entity2uni{"&acirc;"}="00E2";
$entity2uni{"&Acirc;"}="00C2";
$entity2uni{"&agrave;"}="00E0";
$entity2uni{"&Agrave;"}="00C0";
$entity2uni{"&aring;"}="00E5";
$entity2uni{"&Aring;"}="00C5";
$entity2uni{"&atilde;"}="00E3";
$entity2uni{"&Atilde;"}="00C3";
$entity2uni{"&auml;"}="00E4";
$entity2uni{"&Auml;"}="00C4";
$entity2uni{"&aelig;"}="00E6";
$entity2uni{"&AElig;"}="00C6";
$entity2uni{"&ccedil;"}="00E7";
$entity2uni{"&Ccedil;"}="00C7";
$entity2uni{"&eth;"}="00F0";
$entity2uni{"&ETH;"}="00D0";
$entity2uni{"&eacute;"}="00E9";
$entity2uni{"&Eacute;"}="00C9";
$entity2uni{"&ecirc;"}="00EA";
$entity2uni{"&Ecirc;"}="00CA";
$entity2uni{"&egrave;"}="00E8";
$entity2uni{"&Egrave;"}="00C8";
$entity2uni{"&euml;"}="00EB";
$entity2uni{"&Euml;"}="00CB";
$entity2uni{"&iacute;"}="00ED";
$entity2uni{"&Iacute;"}="00CD";
$entity2uni{"&icirc;"}="00EE";
$entity2uni{"&Icirc;"}="00CE";
$entity2uni{"&igrave;"}="00EC";
$entity2uni{"&Igrave;"}="00CC";
$entity2uni{"&iuml;"}="00EF";
$entity2uni{"&Iuml;"}="00CF";
$entity2uni{"&ntilde;"}="00F1";
$entity2uni{"&Ntilde;"}="00D1";
$entity2uni{"&oacute;"}="00F3";
$entity2uni{"&Oacute;"}="00D3";
$entity2uni{"&ocirc;"}="00F4";
$entity2uni{"&Ocirc;"}="00D4";
$entity2uni{"&ograve;"}="00F2";
$entity2uni{"&Ograve;"}="00D2";
$entity2uni{"&oslash;"}="00F8";
$entity2uni{"&Oslash;"}="00D8";
$entity2uni{"&otilde;"}="00F5";
$entity2uni{"&Otilde;"}="00D5";
$entity2uni{"&ouml;"}="00F6";
$entity2uni{"&Ouml;"}="00D6";
$entity2uni{"&szlig;"}="00DF";
$entity2uni{"&thorn;"}="00FE";
$entity2uni{"&THORN;"}="00DE";
$entity2uni{"&uacute;"}="00FA";
$entity2uni{"&Uacute;"}="00DA";
$entity2uni{"&ucirc;"}="00FB";
$entity2uni{"&Ucirc;"}="00DB";
$entity2uni{"&ugrave;"}="00F9";
$entity2uni{"&Ugrave;"}="00D9";
$entity2uni{"&uuml;"}="00FC";
$entity2uni{"&Uuml;"}="00DC";
$entity2uni{"&yacute;"}="00FD";
$entity2uni{"&Yacute;"}="00DD";
$entity2uni{"&yuml;"}="00FF";
$entity2uni{"&abreve;"}="0103";
$entity2uni{"&Abreve;"}="0102";
$entity2uni{"&amacr;"}="0101";
$entity2uni{"&Amacr;"}="0100";
$entity2uni{"&aogon;"}="0105";
$entity2uni{"&Aogon;"}="0104";
$entity2uni{"&cacute;"}="0107";
$entity2uni{"&Cacute;"}="0106";
$entity2uni{"&ccaron;"}="010D";
$entity2uni{"&Ccaron;"}="010C";
$entity2uni{"&ccirc;"}="0109";
$entity2uni{"&Ccirc;"}="0108";
$entity2uni{"&cdot;"}="010B";
$entity2uni{"&Cdot;"}="010A";
$entity2uni{"&dcaron;"}="010F";
$entity2uni{"&Dcaron;"}="010E";
$entity2uni{"&dstrok;"}="0111";
$entity2uni{"&Dstrok;"}="0110";
$entity2uni{"&ecaron;"}="011B";
$entity2uni{"&Ecaron;"}="011A";
$entity2uni{"&edot;"}="0117";
$entity2uni{"&Edot;"}="0116";
$entity2uni{"&emacr;"}="0113";
$entity2uni{"&Emacr;"}="0112";
$entity2uni{"&eogon;"}="0119";
$entity2uni{"&Eogon;"}="0118";
$entity2uni{"&gacute;"}="01F5";
$entity2uni{"&gbreve;"}="011F";
$entity2uni{"&Gbreve;"}="011E";
$entity2uni{"&Gcedil;"}="0122";
$entity2uni{"&gcirc;"}="011D";
$entity2uni{"&Gcirc;"}="011C";
$entity2uni{"&gdot;"}="0121";
$entity2uni{"&Gdot;"}="0120";
$entity2uni{"&hcirc;"}="0125";
$entity2uni{"&Hcirc;"}="0124";
$entity2uni{"&hstrok;"}="0127";
$entity2uni{"&Hstrok;"}="0126";
$entity2uni{"&Idot;"}="0130";
$entity2uni{"&Imacr;"}="012A";
$entity2uni{"&imacr;"}="012B";
$entity2uni{"&ijlig;"}="0133";
$entity2uni{"&IJlig;"}="0132";
$entity2uni{"&inodot;"}="0131";
$entity2uni{"&iogon;"}="012F";
$entity2uni{"&Iogon;"}="012E";
$entity2uni{"&itilde;"}="0129";
$entity2uni{"&Itilde;"}="0128";
$entity2uni{"&jcirc;"}="0135";
$entity2uni{"&Jcirc;"}="0134";
$entity2uni{"&kcedil;"}="0137";
$entity2uni{"&Kcedil;"}="0136";
$entity2uni{"&kgreen;"}="0138";
$entity2uni{"&lacute;"}="013A";
$entity2uni{"&Lacute;"}="0139";
$entity2uni{"&lcaron;"}="013E";
$entity2uni{"&Lcaron;"}="013D";
$entity2uni{"&lcedil;"}="013C";
$entity2uni{"&Lcedil;"}="013B";
$entity2uni{"&lmidot;"}="0140";
$entity2uni{"&Lmidot;"}="013F";
$entity2uni{"&lstrok;"}="0142";
$entity2uni{"&Lstrok;"}="0141";
$entity2uni{"&nacute;"}="0144";
$entity2uni{"&Nacute;"}="0143";
$entity2uni{"&eng;"}="014B";
$entity2uni{"&ENG;"}="014A";
$entity2uni{"&napos;"}="0149";
$entity2uni{"&ncaron;"}="0148";
$entity2uni{"&Ncaron;"}="0147";
$entity2uni{"&ncedil;"}="0146";
$entity2uni{"&Ncedil;"}="0145";
$entity2uni{"&odblac;"}="0151";
$entity2uni{"&Odblac;"}="0150";
$entity2uni{"&Omacr;"}="014C";
$entity2uni{"&omacr;"}="014D";
$entity2uni{"&oelig;"}="0153";
$entity2uni{"&OElig;"}="0152";
$entity2uni{"&racute;"}="0155";
$entity2uni{"&Racute;"}="0154";
$entity2uni{"&rcaron;"}="0159";
$entity2uni{"&Rcaron;"}="0158";
$entity2uni{"&rcedil;"}="0157";
$entity2uni{"&Rcedil;"}="0156";
$entity2uni{"&sacute;"}="015B";
$entity2uni{"&Sacute;"}="015A";
$entity2uni{"&scaron;"}="0161";
$entity2uni{"&Scaron;"}="0160";
$entity2uni{"&scedil;"}="015F";
$entity2uni{"&Scedil;"}="015E";
$entity2uni{"&scirc;"}="015D";
$entity2uni{"&Scirc;"}="015C";
$entity2uni{"&tcaron;"}="0165";
$entity2uni{"&Tcaron;"}="0164";
$entity2uni{"&tcedil;"}="0163";
$entity2uni{"&Tcedil;"}="0162";
$entity2uni{"&tstrok;"}="0167";
$entity2uni{"&Tstrok;"}="0166";
$entity2uni{"&ubreve;"}="016D";
$entity2uni{"&Ubreve;"}="016C";
$entity2uni{"&udblac;"}="0171";
$entity2uni{"&Udblac;"}="0170";
$entity2uni{"&umacr;"}="016B";
$entity2uni{"&Umacr;"}="016A";
$entity2uni{"&uogon;"}="0173";
$entity2uni{"&Uogon;"}="0172";
$entity2uni{"&uring;"}="016F";
$entity2uni{"&Uring;"}="016E";
$entity2uni{"&utilde;"}="0169";
$entity2uni{"&Utilde;"}="0168";
$entity2uni{"&wcirc;"}="0175";
$entity2uni{"&Wcirc;"}="0174";
$entity2uni{"&ycirc;"}="0177";
$entity2uni{"&Ycirc;"}="0176";
$entity2uni{"&Yuml;"}="0178";
$entity2uni{"&zacute;"}="017A";
$entity2uni{"&Zacute;"}="0179";
$entity2uni{"&zcaron;"}="017E";
$entity2uni{"&Zcaron;"}="017D";
$entity2uni{"&zdot;"}="017C";
$entity2uni{"&Zdot;"}="017B";
$entity2uni{"&emsp;"}="2003";
$entity2uni{"&ensp;"}="2002";
$entity2uni{"&emsp13;"}="2004";
$entity2uni{"&emsp14;"}="2005";
$entity2uni{"&numsp;"}="2007";
$entity2uni{"&puncsp;"}="2008";
$entity2uni{"&thinsp;"}="2009";
$entity2uni{"&hairsp;"}="200A";
$entity2uni{"&mdash;"}="2014";
$entity2uni{"&ndash;"}="2013";
$entity2uni{"&dash;"}="2010";
$entity2uni{"&blank;"}="2423";
$entity2uni{"&hellip;"}="2026";
$entity2uni{"&nldr;"}="2025";
$entity2uni{"&frac13;"}="2153";
$entity2uni{"&frac23;"}="2154";
$entity2uni{"&frac15;"}="2155";
$entity2uni{"&frac25;"}="2156";
$entity2uni{"&frac35;"}="2157";
$entity2uni{"&frac45;"}="2158";
$entity2uni{"&frac16;"}="2159";
$entity2uni{"&frac56;"}="215A";
$entity2uni{"&incare;"}="2105";
$entity2uni{"&block;"}="2588";
$entity2uni{"&uhblk;"}="2580";
$entity2uni{"&lhblk;"}="2584";
$entity2uni{"&blk14;"}="2591";
$entity2uni{"&blk12;"}="2592";
$entity2uni{"&blk34;"}="2593";
$entity2uni{"&marker;"}="25AE";
$entity2uni{"&cir;"}="25CB";
$entity2uni{"&squ;"}="25A1";
$entity2uni{"&rect;"}="25AD";
$entity2uni{"&utri;"}="25B5";
$entity2uni{"&dtri;"}="25BF";
$entity2uni{"&star;"}="22C6";
$entity2uni{"&bull;"}="2022";
$entity2uni{"&squf;"}="25AA";
$entity2uni{"&utrif;"}="25B4";
$entity2uni{"&dtrif;"}="25BE";
$entity2uni{"&ltrif;"}="25C2";
$entity2uni{"&rtrif;"}="25B8";
$entity2uni{"&clubs;"}="2663";
$entity2uni{"&diams;"}="2666";
$entity2uni{"&hearts;"}="2661";
$entity2uni{"&spades;"}="2660";
$entity2uni{"&malt;"}="2720";
$entity2uni{"&dagger;"}="2020";
$entity2uni{"&Dagger;"}="2021";
$entity2uni{"&check;"}="2713";
$entity2uni{"&cross;"}="2717";
$entity2uni{"&sharp;"}="266F";
$entity2uni{"&flat;"}="266D";
$entity2uni{"&male;"}="2642";
$entity2uni{"&female;"}="2640";
$entity2uni{"&phone;"}="260E";
$entity2uni{"&telrec;"}="2315";
$entity2uni{"&copysr;"}="2117";
$entity2uni{"&caret;"}="2041";
$entity2uni{"&lsquor;"}="201A";
$entity2uni{"&ldquor;"}="201E";
$entity2uni{"&mldr;"}="2026";
$entity2uni{"&rdquor;"}="201D";
$entity2uni{"&rsquor;"}="2019";
$entity2uni{"&vellip;"}="22EE";
$entity2uni{"&hybull;"}="2043";
$entity2uni{"&loz;"}="25CA";
$entity2uni{"&ltri;"}="25C3";
$entity2uni{"&rtri;"}="25B9";
$entity2uni{"&starf;"}="2605";
$entity2uni{"&natur;"}="266E";
$entity2uni{"&rx;"}="211E";
$entity2uni{"&sext;"}="2736";
$entity2uni{"&target;"}="2316";
$entity2uni{"&dlcrop;"}="230D";
$entity2uni{"&drcrop;"}="230C";
$entity2uni{"&ulcrop;"}="230F";
$entity2uni{"&urcrop;"}="230E";
$entity2uni{"&aleph;"}="2135";
$entity2uni{"&and;"}="2227";
$entity2uni{"&ang90;"}="221F";
$entity2uni{"&angsph;"}="2222";
$entity2uni{"&ap;"}="2248";
$entity2uni{"&becaus;"}="2235";
$entity2uni{"&bottom;"}="22A5";
$entity2uni{"&cap;"}="2229";
$entity2uni{"&cong;"}="2245";
$entity2uni{"&conint;"}="222E";
$entity2uni{"&cup;"}="222A";
$entity2uni{"&equiv;"}="2261";
$entity2uni{"&exist;"}="2203";
$entity2uni{"&forall;"}="2200";
$entity2uni{"&fnof;"}="0192";
$entity2uni{"&ge;"}="2265";
$entity2uni{"&infin;"}="221E";
$entity2uni{"&int;"}="222B";
$entity2uni{"&isin;"}="2208";
$entity2uni{"&lang;"}="3008";
$entity2uni{"&lArr;"}="21D0";
$entity2uni{"&le;"}="2264";
$entity2uni{"&minus;"}="2212";
$entity2uni{"&mnplus;"}="2213";
$entity2uni{"&nabla;"}="2207";
$entity2uni{"&ne;"}="2260";
$entity2uni{"&ni;"}="220B";
$entity2uni{"&or;"}="2228";
$entity2uni{"&par;"}="2225";
$entity2uni{"&part;"}="2202";
$entity2uni{"&permil;"}="2030";
$entity2uni{"&perp;"}="22A5";
$entity2uni{"&prime;"}="2032";
$entity2uni{"&Prime;"}="2033";
$entity2uni{"&prop;"}="221D";
$entity2uni{"&radic;"}="221A";
$entity2uni{"&rang;"}="3009";
$entity2uni{"&rArr;"}="21D2";
$entity2uni{"&sim;"}="223C";
$entity2uni{"&sime;"}="2243";
$entity2uni{"&square;"}="25A1";
$entity2uni{"&sub;"}="2282";
$entity2uni{"&sube;"}="2286";
$entity2uni{"&sup;"}="2283";
$entity2uni{"&supe;"}="2287";
$entity2uni{"&there4;"}="2234";
$entity2uni{"&Verbar;"}="2016";
$entity2uni{"&angst;"}="212B";
$entity2uni{"&bernou;"}="212C";
$entity2uni{"&compfn;"}="2218";
$entity2uni{"&Dot;"}="00A8";
$entity2uni{"&DotDot;"}="20DC";
$entity2uni{"&hamilt;"}="210B";
$entity2uni{"&lagran;"}="2112";
$entity2uni{"&lowast;"}="2217";
$entity2uni{"&notin;"}="2209";
$entity2uni{"&order;"}="2134";
$entity2uni{"&phmmat;"}="2133";
$entity2uni{"&tdot;"}="20DB";
$entity2uni{"&tprime;"}="2034";
$entity2uni{"&wedgeq;"}="2259";
$entity2uni{"&acute;"}="00B4";
$entity2uni{"&breve;"}="02D8";
$entity2uni{"&caron;"}="02C7";
$entity2uni{"&cedil;"}="00B8";
$entity2uni{"&circ;"}="005E";
$entity2uni{"&dblac;"}="02DD";
$entity2uni{"&die;"}="00A8";
$entity2uni{"&dot;"}="02D9";
$entity2uni{"&grave;"}="0060";
$entity2uni{"&macr;"}="00AF";
$entity2uni{"&ogon;"}="02DB";
$entity2uni{"&ring;"}="02DA";
$entity2uni{"&tilde;"}="02DC";
$entity2uni{"&uml;"}="00A8";

$entity2uni{"&half;"}="00BD";
$entity2uni{"&frac12;"}="00BD";
$entity2uni{"&frac14;"}="00BC";
$entity2uni{"&frac34;"}="00BE";
$entity2uni{"&frac18;"}="215B";
$entity2uni{"&frac38;"}="215C";
$entity2uni{"&frac58;"}="215D";
$entity2uni{"&frac78;"}="215E";
$entity2uni{"&sup1;"}="00B9";
$entity2uni{"&sup2;"}="00B2";
$entity2uni{"&sup3;"}="00B3";
$entity2uni{"&plus;"}="002B";
$entity2uni{"&plusmn;"}="00B1";
$entity2uni{"&lt;"}="003C";
$entity2uni{"&equals;"}="003D";
$entity2uni{"&gt;"}="003E";
$entity2uni{"&divide;"}="00F7";
$entity2uni{"&times;"}="00D7";
$entity2uni{"&curren;"}="00A4";
$entity2uni{"&pound;"}="00A3";
$entity2uni{"&dollar;"}="0024";
$entity2uni{"&cent;"}="00A2";
$entity2uni{"&yen;"}="00A5";
$entity2uni{"&num;"}="0023";
$entity2uni{"&euro;"}="20AC";
$entity2uni{"&percnt;"}="0025";
$entity2uni{"&amp;"}="0026";
$entity2uni{"&ast;"}="002A";
$entity2uni{"&commat;"}="0040";
$entity2uni{"&lsqb;"}="005B";
$entity2uni{"&bsol;"}="005C";
$entity2uni{"&rsqb;"}="005D";
$entity2uni{"&lcub;"}="007B";
$entity2uni{"&horbar;"}="2015";
$entity2uni{"&verbar;"}="007C";
$entity2uni{"&rcub;"}="007D";
$entity2uni{"&micro;"}="00B5";
$entity2uni{"&ohm;"}="2126";
$entity2uni{"&deg;"}="00B0";
$entity2uni{"&ordm;"}="00BA";
$entity2uni{"&ordf;"}="00AA";
$entity2uni{"&sect;"}="00A7";
$entity2uni{"&para;"}="00B6";
$entity2uni{"&middot;"}="00B7";
$entity2uni{"&larr;"}="2190";
$entity2uni{"&rarr;"}="2192";
$entity2uni{"&uarr;"}="2191";
$entity2uni{"&darr;"}="2193";
$entity2uni{"&copy;"}="00A9";
$entity2uni{"&reg;"}="00AE";
$entity2uni{"&trade;"}="2122";
$entity2uni{"&brvbar;"}="00A6";
$entity2uni{"&not;"}="00AC";
$entity2uni{"&sung;"}="266A";
$entity2uni{"&excl;"}="0021";
$entity2uni{"&iexcl;"}="00A1";
$entity2uni{"&quot;"}="0022";
$entity2uni{"&apos;"}="0027";
$entity2uni{"&lpar;"}="0028";
$entity2uni{"&rpar;"}="0029";
$entity2uni{"&comma;"}="002C";
$entity2uni{"&lowbar;"}="005F";
$entity2uni{"&hyphen;"}="2010";
$entity2uni{"&period;"}="002E";
$entity2uni{"&sol;"}="002F";
$entity2uni{"&colon;"}="003A";
$entity2uni{"&semi;"}="003B";
$entity2uni{"&quest;"}="003F";
$entity2uni{"&iquest;"}="00BF";
$entity2uni{"&laquo;"}="00AB";
$entity2uni{"&raquo;"}="00BB";
$entity2uni{"&lsquo;"}="2018";
$entity2uni{"&rsquo;"}="2019";
$entity2uni{"&ldquo;"}="201C";
$entity2uni{"&rdquo;"}="201D";
$entity2uni{"&nbsp;"}="00A0";
$entity2uni{"&shy;"}="00AD";
$entity2uni{"&agr;"}="03B1";
$entity2uni{"&Agr;"}="0391";
$entity2uni{"&bgr;"}="03B2";
$entity2uni{"&Bgr;"}="0392";
$entity2uni{"&ggr;"}="03B3";
$entity2uni{"&Ggr;"}="0393";
$entity2uni{"&dgr;"}="03B4";
$entity2uni{"&Dgr;"}="0394";
$entity2uni{"&egr;"}="03B5";
$entity2uni{"&Egr;"}="0395";
$entity2uni{"&zgr;"}="03B6";
$entity2uni{"&Zgr;"}="0396";
$entity2uni{"&eegr;"}="03B7";
$entity2uni{"&EEgr;"}="0397";
$entity2uni{"&thgr;"}="03B8";
$entity2uni{"&THgr;"}="0398";
$entity2uni{"&igr;"}="03B9";
$entity2uni{"&Igr;"}="0399";
$entity2uni{"&kgr;"}="03BA";
$entity2uni{"&Kgr;"}="039A";
$entity2uni{"&lgr;"}="03BB";
$entity2uni{"&Lgr;"}="039B";
$entity2uni{"&mgr;"}="03BC";
$entity2uni{"&Mgr;"}="039C";
$entity2uni{"&ngr;"}="03BD";
$entity2uni{"&Ngr;"}="039D";
$entity2uni{"&xgr;"}="03BE";
$entity2uni{"&Xgr;"}="039E";
$entity2uni{"&ogr;"}="03BF";
$entity2uni{"&Ogr;"}="039F";
$entity2uni{"&pgr;"}="03C0";
$entity2uni{"&Pgr;"}="03A0";
$entity2uni{"&rgr;"}="03C1";
$entity2uni{"&Rgr;"}="03A1";
$entity2uni{"&sgr;"}="03C3";
$entity2uni{"&Sgr;"}="03A3";
$entity2uni{"&sfgr;"}="03C2";
$entity2uni{"&tgr;"}="03C4";
$entity2uni{"&Tgr;"}="03A4";
$entity2uni{"&ugr;"}="03C5";
$entity2uni{"&Ugr;"}="03A5";
$entity2uni{"&phgr;"}="03C6";
$entity2uni{"&PHgr;"}="03A6";
$entity2uni{"&khgr;"}="03C7";
$entity2uni{"&KHgr;"}="03A7";
$entity2uni{"&psgr;"}="03C8";
$entity2uni{"&PSgr;"}="03A8";
$entity2uni{"&ohgr;"}="03C9";
$entity2uni{"&OHgr;"}="03A9";
$entity2uni{"&aacgr;"}="03AC";
$entity2uni{"&Aacgr;"}="0386";
$entity2uni{"&eacgr;"}="03AD";
$entity2uni{"&Eacgr;"}="0388";
$entity2uni{"&eeacgr;"}="03AE";
$entity2uni{"&EEacgr;"}="0389";
$entity2uni{"&idigr;"}="03CA";
$entity2uni{"&Idigr;"}="03AA";
$entity2uni{"&iacgr;"}="03AF";
$entity2uni{"&Iacgr;"}="038A";
$entity2uni{"&idiagr;"}="0390";
$entity2uni{"&oacgr;"}="03CC";
$entity2uni{"&Oacgr;"}="038C";
$entity2uni{"&udigr;"}="03CB";
$entity2uni{"&Udigr;"}="03AB";
$entity2uni{"&uacgr;"}="03CD";
$entity2uni{"&Uacgr;"}="038E";
$entity2uni{"&udiagr;"}="03B0";
$entity2uni{"&ohacgr;"}="03CE";
$entity2uni{"&OHacgr;"}="038F";
$entity2uni{"&alpha;"}="03B1";
$entity2uni{"&beta;"}="03B2";
$entity2uni{"&gamma;"}="03B3";
$entity2uni{"&Gamma;"}="0393";
$entity2uni{"&gammad;"}="03DC";
$entity2uni{"&delta;"}="03B4";
$entity2uni{"&Delta;"}="0394";
$entity2uni{"&epsi;"}="03B5";
$entity2uni{"&epsiv;"}="025B";
$entity2uni{"&epsis;"}="03B5";
$entity2uni{"&zeta;"}="03B6";
$entity2uni{"&eta;"}="03B7";
$entity2uni{"&thetas;"}="03B8";
$entity2uni{"&Theta;"}="0398";
$entity2uni{"&thetav;"}="03D1";
$entity2uni{"&iota;"}="03B9";
$entity2uni{"&kappa;"}="03BA";
$entity2uni{"&kappav;"}="03F0";
$entity2uni{"&lambda;"}="03BB";
$entity2uni{"&Lambda;"}="039B";
$entity2uni{"&mu;"}="03BC";
$entity2uni{"&nu;"}="03BD";
$entity2uni{"&xi;"}="03BE";
$entity2uni{"&Xi;"}="039E";
$entity2uni{"&pi;"}="03C0";
$entity2uni{"&piv;"}="03D6";
$entity2uni{"&Pi;"}="03A0";
$entity2uni{"&rho;"}="03C1";
$entity2uni{"&rhov;"}="03F1";
$entity2uni{"&sigma;"}="03C3";
$entity2uni{"&Sigma;"}="03A3";
$entity2uni{"&sigmav;"}="03C2";
$entity2uni{"&tau;"}="03C4";
$entity2uni{"&upsi;"}="03C5";
$entity2uni{"&Upsi;"}="03D2";
$entity2uni{"&phis;"}="03C6";
$entity2uni{"&Phi;"}="03A6";
$entity2uni{"&phiv;"}="03D5";
$entity2uni{"&chi;"}="03C7";
$entity2uni{"&psi;"}="03C8";
$entity2uni{"&Psi;"}="03A8";
$entity2uni{"&omega;"}="03C9";
$entity2uni{"&Omega;"}="03A9";
$entity2uni{"&b.alpha;"}="03B1";
$entity2uni{"&b.beta;"}="03B2";
$entity2uni{"&b.gamma;"}="03B3";
$entity2uni{"&b.Gamma;"}="0393";
$entity2uni{"&b.gammad;"}="03DD";
$entity2uni{"&b.delta;"}="03B4";
$entity2uni{"&b.Delta;"}="0394";
$entity2uni{"&b.epsi;"}="03B5";
$entity2uni{"&b.epsiv;"}="025B";
$entity2uni{"&b.epsis;"}="03B5";
$entity2uni{"&b.zeta;"}="03B6";
$entity2uni{"&b.eta;"}="03B7";
$entity2uni{"&b.thetas;"}="03B8";
$entity2uni{"&b.Theta;"}="0398";
$entity2uni{"&b.thetav;"}="03D1";
$entity2uni{"&b.iota;"}="03B9";
$entity2uni{"&b.kappa;"}="03BA";
$entity2uni{"&b.kappav;"}="03F0";
$entity2uni{"&b.lambda;"}="03BB";
$entity2uni{"&b.Lambda;"}="039B";
$entity2uni{"&b.mu;"}="03BC";
$entity2uni{"&b.nu;"}="03BD";
$entity2uni{"&b.xi;"}="03BE";
$entity2uni{"&b.Xi;"}="039E";
$entity2uni{"&b.pi;"}="03C0";
$entity2uni{"&b.Pi;"}="03A0";
$entity2uni{"&b.piv;"}="03D6";
$entity2uni{"&b.rho;"}="03C1";
$entity2uni{"&b.rhov;"}="03F1";
$entity2uni{"&b.sigma;"}="03C3";
$entity2uni{"&b.Sigma;"}="03A3";
$entity2uni{"&b.sigmav;"}="03C2";
$entity2uni{"&b.tau;"}="03C4";
$entity2uni{"&b.upsi;"}="03C5";
$entity2uni{"&b.Upsi;"}="03D2";
$entity2uni{"&b.phis;"}="03C6";
$entity2uni{"&b.Phi;"}="03A6";
$entity2uni{"&b.phiv;"}="03D5";
$entity2uni{"&b.chi;"}="03C7";
$entity2uni{"&b.psi;"}="03C8";
$entity2uni{"&b.Psi;"}="03A8";
$entity2uni{"&b.omega;"}="03C9";
$entity2uni{"&b.Omega;"}="03A9";
$entity2uni{"&rceil;"}="2309";
$entity2uni{"&rfloor;"}="230B";
$entity2uni{"&rpargt;"}="2994";
$entity2uni{"&urcorn;"}="231D";
$entity2uni{"&drcorn;"}="231F";
$entity2uni{"&lceil;"}="2308";
$entity2uni{"&lfloor;"}="230A";
$entity2uni{"&ulcorn;"}="231C";
$entity2uni{"&dlcorn;"}="231E";
$entity2uni{"&gne;"}="2269";
$entity2uni{"&gnE;"}="2269";
$entity2uni{"&gnsim;"}="22E7";
$entity2uni{"&lnap;"}="2A89";
$entity2uni{"&lnE;"}="2268";
$entity2uni{"&lne;"}="2268";
$entity2uni{"&lnsim;"}="22E6";
$entity2uni{"&nap;"}="2249";
$entity2uni{"&ncong;"}="2247";
$entity2uni{"&nequiv;"}="2262";
$entity2uni{"&ngE;"}="2271";
$entity2uni{"&nge;"}="2271";
$entity2uni{"&nges;"}="2271";
$entity2uni{"&ngt;"}="226F";
$entity2uni{"&nle;"}="2270";
$entity2uni{"&nlE;"}="2270";
$entity2uni{"&nles;"}="2270";
$entity2uni{"&nlt;"}="226E";
$entity2uni{"&nltri;"}="22EA";
$entity2uni{"&nltrie;"}="22EC";
$entity2uni{"&nmid;"}="2224";
$entity2uni{"&npar;"}="2226";
$entity2uni{"&npr;"}="2280";
$entity2uni{"&nrtri;"}="22EB";
$entity2uni{"&nrtrie;"}="22ED";
$entity2uni{"&nsc;"}="2281";
$entity2uni{"&nsim;"}="2241";
$entity2uni{"&nsime;"}="2244";
$entity2uni{"&nsmid;"}="2224";
$entity2uni{"&nsub;"}="2284";
$entity2uni{"&nsube;"}="2288";
$entity2uni{"&nsubE;"}="2288";
$entity2uni{"&nsup;"}="2285";
$entity2uni{"&nsupE;"}="2289";
$entity2uni{"&nsupe;"}="2289";
$entity2uni{"&nvdash;"}="22AC";
$entity2uni{"&nvDash;"}="22AD";
$entity2uni{"&nVDash;"}="22AF";
$entity2uni{"&nVdash;"}="22AE";
$entity2uni{"&prnap;"}="22E8";
$entity2uni{"&prnE;"}="2AB5";
$entity2uni{"&prnsim;"}="22E8";
$entity2uni{"&scnap;"}="22E9";
$entity2uni{"&scnE;"}="2AB6";
$entity2uni{"&scnsim;"}="22E9";
$entity2uni{"&subne;"}="228A";
$entity2uni{"&subnE;"}="228A";
$entity2uni{"&supne;"}="228B";
$entity2uni{"&supnE;"}="228B";
$entity2uni{"&cularr;"}="21B6";
$entity2uni{"&curarr;"}="21B7";
$entity2uni{"&dArr;"}="21D3";
$entity2uni{"&darr2;"}="21CA";
$entity2uni{"&dharl;"}="21C3";
$entity2uni{"&dharr;"}="21C2";
$entity2uni{"&lAarr;"}="21DA";
$entity2uni{"&Larr;"}="219E";
$entity2uni{"&larr2;"}="21C7";
$entity2uni{"&larrhk;"}="21A9";
$entity2uni{"&larrlp;"}="21AB";
$entity2uni{"&larrtl;"}="21A2";
$entity2uni{"&lhard;"}="21BD";
$entity2uni{"&lharu;"}="21BC";
$entity2uni{"&hArr;"}="21D4";
$entity2uni{"&harr;"}="2194";
$entity2uni{"&lrarr2;"}="21C6";
$entity2uni{"&rlarr2;"}="21C4";
$entity2uni{"&harrw;"}="21AD";
$entity2uni{"&rlhar2;"}="21CC";
$entity2uni{"&lrhar2;"}="21CB";
$entity2uni{"&lsh;"}="21B0";
$entity2uni{"&map;"}="21A6";
$entity2uni{"&mumap;"}="22B8";
$entity2uni{"&nearr;"}="2197";
$entity2uni{"&nlArr;"}="21CD";
$entity2uni{"&nlarr;"}="219A";
$entity2uni{"&nhArr;"}="21CE";
$entity2uni{"&nharr;"}="21AE";
$entity2uni{"&nrarr;"}="219B";
$entity2uni{"&nrArr;"}="21CF";
$entity2uni{"&nwarr;"}="2196";
$entity2uni{"&olarr;"}="21BA";
$entity2uni{"&orarr;"}="21BB";
$entity2uni{"&rAarr;"}="21DB";
$entity2uni{"&Rarr;"}="21A0";
$entity2uni{"&rarr2;"}="21C9";
$entity2uni{"&rarrhk;"}="21AA";
$entity2uni{"&rarrlp;"}="21AC";
$entity2uni{"&rarrtl;"}="21A3";
$entity2uni{"&rarrw;"}="21DD";
$entity2uni{"&rhard;"}="21C1";
$entity2uni{"&rharu;"}="21C0";
$entity2uni{"&rsh;"}="21B1";
$entity2uni{"&drarr;"}="2198";
$entity2uni{"&dlarr;"}="2199";
$entity2uni{"&uArr;"}="21D1";
$entity2uni{"&uarr2;"}="21C8";
$entity2uni{"&vArr;"}="21D5";
$entity2uni{"&varr;"}="2195";
$entity2uni{"&uharl;"}="21BF";
$entity2uni{"&uharr;"}="21BE";
$entity2uni{"&Barwed;"}="2306";
$entity2uni{"&barwed;"}="22BC";
$entity2uni{"&Cap;"}="22D2";
$entity2uni{"&Cup;"}="22D3";
$entity2uni{"&cuvee;"}="22CE";
$entity2uni{"&cuwed;"}="22CF";
$entity2uni{"&diam;"}="22C4";
$entity2uni{"&divonx;"}="22C7";
$entity2uni{"&intcal;"}="22BA";
$entity2uni{"&lthree;"}="22CB";
$entity2uni{"&ltimes;"}="22C9";
$entity2uni{"&minusb;"}="229F";
$entity2uni{"&oast;"}="229B";
$entity2uni{"&ocir;"}="229A";
$entity2uni{"&odash;"}="229D";
$entity2uni{"&odot;"}="2299";
$entity2uni{"&ominus;"}="2296";
$entity2uni{"&oplus;"}="2295";
$entity2uni{"&osol;"}="2298";
$entity2uni{"&otimes;"}="2297";
$entity2uni{"&plusb;"}="229E";
$entity2uni{"&plusdo;"}="2214";
$entity2uni{"&rthree;"}="22CC";
$entity2uni{"&rtimes;"}="22CA";
$entity2uni{"&sdot;"}="00B7";
$entity2uni{"&sdotb;"}="22A1";
$entity2uni{"&setmn;"}="2216";
$entity2uni{"&sqcap;"}="2293";
$entity2uni{"&sqcup;"}="2294";
$entity2uni{"&sstarf;"}="22C6";
$entity2uni{"&timesb;"}="22A0";
$entity2uni{"&top;"}="22A4";
$entity2uni{"&uplus;"}="228E";
$entity2uni{"&wreath;"}="2240";
$entity2uni{"&xcirc;"}="25EF";
$entity2uni{"&xdtri;"}="25BD";
$entity2uni{"&xutri;"}="25B3";
$entity2uni{"&coprod;"}="2210";
$entity2uni{"&prod;"}="220F";
$entity2uni{"&sum;"}="2211";
$entity2uni{"&ang;"}="221F";
$entity2uni{"&angmsd;"}="2221";
$entity2uni{"&beth;"}="2136";
$entity2uni{"&bprime;"}="2035";
$entity2uni{"&comp;"}="2201";
$entity2uni{"&daleth;"}="2138";
$entity2uni{"&ell;"}="2113";
$entity2uni{"&gimel;"}="2137";
$entity2uni{"&image;"}="2111";
$entity2uni{"&inodot;"}="0131";
$entity2uni{"&nexist;"}="2204";
$entity2uni{"&oS;"}="24C8";
$entity2uni{"&planck;"}="210F";
$entity2uni{"&real;"}="211C";
$entity2uni{"&sbsol;"}="005C";
$entity2uni{"&vprime;"}="2032";
$entity2uni{"&weierp;"}="2118";
$entity2uni{"&ape;"}="224A";
$entity2uni{"&asymp;"}="224D";
$entity2uni{"&bcong;"}="224C";
$entity2uni{"&bowtie;"}="22C8";
$entity2uni{"&bsim;"}="223D";
$entity2uni{"&bsime;"}="22CD";
$entity2uni{"&bump;"}="224E";
$entity2uni{"&bumpe;"}="224F";
$entity2uni{"&cire;"}="2257";
$entity2uni{"&colone;"}="2254";
$entity2uni{"&cuepr;"}="22DE";
$entity2uni{"&cuesc;"}="22DF";
$entity2uni{"&cupre;"}="227C";
$entity2uni{"&dashv;"}="22A3";
$entity2uni{"&ecir;"}="2256";
$entity2uni{"&ecolon;"}="2255";
$entity2uni{"&eDot;"}="2251";
$entity2uni{"&esdot;"}="2250";
$entity2uni{"&efDot;"}="2252";
$entity2uni{"&egs;"}="22DD";
$entity2uni{"&els;"}="22DC";
$entity2uni{"&erDot;"}="2253";
$entity2uni{"&fork;"}="22D4";
$entity2uni{"&frown;"}="2322";
$entity2uni{"&gap;"}="2273";
$entity2uni{"&gsdot;"}="22D7";
$entity2uni{"&gE;"}="2267";
$entity2uni{"&gel;"}="22DB";
$entity2uni{"&gEl;"}="22DB";
$entity2uni{"&Gg;"}="22D9";
$entity2uni{"&gl;"}="2277";
$entity2uni{"&gsim;"}="2273";
$entity2uni{"&Gt;"}="226B";
$entity2uni{"&lap;"}="2272";
$entity2uni{"&ldot;"}="22D6";
$entity2uni{"&lE;"}="2266";
$entity2uni{"&lEg;"}="22DA";
$entity2uni{"&leg;"}="22DA";
$entity2uni{"&lg;"}="2276";
$entity2uni{"&Ll;"}="22D8";
$entity2uni{"&lsim;"}="2272";
$entity2uni{"&Lt;"}="226A";
$entity2uni{"&ltrie;"}="22B4";
$entity2uni{"&mid;"}="2223";
$entity2uni{"&models;"}="22A7";
$entity2uni{"&pr;"}="227A";
$entity2uni{"&prap;"}="227E";
$entity2uni{"&prsim;"}="227E";
$entity2uni{"&rtrie;"}="22B5";
$entity2uni{"&samalg;"}="2210";
$entity2uni{"&sc;"}="227B";
$entity2uni{"&scap;"}="227F";
$entity2uni{"&sccue;"}="227D";
$entity2uni{"&sce;"}="227D";
$entity2uni{"&scsim;"}="227F";
$entity2uni{"&sfrown;"}="2322";
$entity2uni{"&smid;"}="2223";
$entity2uni{"&smile;"}="2323";
$entity2uni{"&sqsub;"}="228F";
$entity2uni{"&sqsube;"}="2291";
$entity2uni{"&sqsup;"}="2290";
$entity2uni{"&sqsupe;"}="2292";
$entity2uni{"&ssmile;"}="2323";
$entity2uni{"&Sub;"}="22D0";
$entity2uni{"&subE;"}="2286";
$entity2uni{"&Sup;"}="22D1";
$entity2uni{"&supE;"}="2287";
$entity2uni{"&thkap;"}="E306";
$entity2uni{"&thksim;"}="E429";
$entity2uni{"&trie;"}="225C";
$entity2uni{"&twixt;"}="226C";
$entity2uni{"&vdash;"}="22A2";
$entity2uni{"&Vdash;"}="22A9";
$entity2uni{"&vDash;"}="22A8";
$entity2uni{"&veebar;"}="22BB";
$entity2uni{"&vltri;"}="22B2";
$entity2uni{"&vprop;"}="221D";
$entity2uni{"&vrtri;"}="22B3";
$entity2uni{"&Vvdash;"}="22AA";
$entity2uni{"&acy;"}="0430";
$entity2uni{"&Acy;"}="0410";
$entity2uni{"&bcy;"}="0431";
$entity2uni{"&Bcy;"}="0411";
$entity2uni{"&vcy;"}="0432";
$entity2uni{"&Vcy;"}="0412";
$entity2uni{"&gcy;"}="0433";
$entity2uni{"&Gcy;"}="0413";
$entity2uni{"&dcy;"}="0434";
$entity2uni{"&Dcy;"}="0414";
$entity2uni{"&iecy;"}="0435";
$entity2uni{"&IEcy;"}="0415";
$entity2uni{"&iocy;"}="0451";
$entity2uni{"&IOcy;"}="0401";
$entity2uni{"&zhcy;"}="0436";
$entity2uni{"&ZHcy;"}="0416";
$entity2uni{"&zcy;"}="0437";
$entity2uni{"&Zcy;"}="0417";
$entity2uni{"&icy;"}="0438";
$entity2uni{"&Icy;"}="0418";
$entity2uni{"&jcy;"}="0439";
$entity2uni{"&Jcy;"}="0419";
$entity2uni{"&kcy;"}="043A";
$entity2uni{"&Kcy;"}="041A";
$entity2uni{"&lcy;"}="043B";
$entity2uni{"&Lcy;"}="041B";
$entity2uni{"&mcy;"}="043C";
$entity2uni{"&Mcy;"}="041C";
$entity2uni{"&ncy;"}="043D";
$entity2uni{"&Ncy;"}="041D";
$entity2uni{"&ocy;"}="043E";
$entity2uni{"&Ocy;"}="041E";
$entity2uni{"&pcy;"}="043F";
$entity2uni{"&Pcy;"}="041F";
$entity2uni{"&rcy;"}="0440";
$entity2uni{"&Rcy;"}="0420";
$entity2uni{"&scy;"}="0441";
$entity2uni{"&Scy;"}="0421";
$entity2uni{"&tcy;"}="0442";
$entity2uni{"&Tcy;"}="0422";
$entity2uni{"&ucy;"}="0443";
$entity2uni{"&Ucy;"}="0423";
$entity2uni{"&fcy;"}="0444";
$entity2uni{"&Fcy;"}="0424";
$entity2uni{"&khcy;"}="0445";
$entity2uni{"&KHcy;"}="0425";
$entity2uni{"&tscy;"}="0446";
$entity2uni{"&TScy;"}="0426";
$entity2uni{"&chcy;"}="0447";
$entity2uni{"&CHcy;"}="0427";
$entity2uni{"&shcy;"}="0448";
$entity2uni{"&SHcy;"}="0428";
$entity2uni{"&shchcy;"}="0449";
$entity2uni{"&SHCHcy;"}="0429";
$entity2uni{"&hardcy;"}="044A";
$entity2uni{"&HARDcy;"}="042A";
$entity2uni{"&ycy;"}="044B";
$entity2uni{"&Ycy;"}="042B";
$entity2uni{"&softcy;"}="044C";
$entity2uni{"&SOFTcy;"}="042C";
$entity2uni{"&ecy;"}="044D";
$entity2uni{"&Ecy;"}="042D";
$entity2uni{"&yucy;"}="044E";
$entity2uni{"&YUcy;"}="042E";
$entity2uni{"&yacy;"}="044F";
$entity2uni{"&YAcy;"}="042F";
$entity2uni{"&numero;"}="2116";
$entity2uni{"&djcy;"}="0452";
$entity2uni{"&DJcy;"}="0402";
$entity2uni{"&gjcy;"}="0453";
$entity2uni{"&GJcy;"}="0403";
$entity2uni{"&jukcy;"}="0454";
$entity2uni{"&Jukcy;"}="0404";
$entity2uni{"&dscy;"}="0455";
$entity2uni{"&DScy;"}="0405";
$entity2uni{"&iukcy;"}="0456";
$entity2uni{"&Iukcy;"}="0406";
$entity2uni{"&yicy;"}="0457";
$entity2uni{"&YIcy;"}="0407";
$entity2uni{"&jsercy;"}="0458";
$entity2uni{"&Jsercy;"}="0408";
$entity2uni{"&ljcy;"}="0459";
$entity2uni{"&LJcy;"}="0409";
$entity2uni{"&njcy;"}="045A";
$entity2uni{"&NJcy;"}="040A";
$entity2uni{"&tshcy;"}="045B";
$entity2uni{"&TSHcy;"}="040B";
$entity2uni{"&kjcy;"}="045C";
$entity2uni{"&KJcy;"}="040C";
$entity2uni{"&ubrcy;"}="045E";
$entity2uni{"&Ubrcy;"}="040E";
$entity2uni{"&dzcy;"}="045F";
$entity2uni{"&DZcy;"}="040F";
$entity2uni{"&boxh;"}="2500";
$entity2uni{"&boxv;"}="2502";
$entity2uni{"&boxur;"}="2514";
$entity2uni{"&boxul;"}="2518";
$entity2uni{"&boxdl;"}="2510";
$entity2uni{"&boxdr;"}="250C";
$entity2uni{"&boxvr;"}="251C";
$entity2uni{"&boxhu;"}="2534";
$entity2uni{"&boxvl;"}="2524";
$entity2uni{"&boxhd;"}="252C";
$entity2uni{"&boxvh;"}="253C";
$entity2uni{"&boxvR;"}="255E";
$entity2uni{"&boxhU;"}="2568";
$entity2uni{"&boxvL;"}="2561";
$entity2uni{"&boxhD;"}="2565";
$entity2uni{"&boxvH;"}="256A";
$entity2uni{"&boxH;"}="2550";
$entity2uni{"&boxV;"}="2551";
$entity2uni{"&boxUR;"}="255A";
$entity2uni{"&boxUL;"}="255D";
$entity2uni{"&boxDL;"}="2557";
$entity2uni{"&boxDR;"}="2554";
$entity2uni{"&boxVR;"}="2560";
$entity2uni{"&boxHU;"}="2569";
$entity2uni{"&boxVL;"}="2563";
$entity2uni{"&boxHD;"}="2566";
$entity2uni{"&boxVH;"}="256C";
$entity2uni{"&boxVr;"}="255F";
$entity2uni{"&boxHu;"}="2567";
$entity2uni{"&boxVl;"}="2562";
$entity2uni{"&boxHd;"}="2564";
$entity2uni{"&boxVh;"}="256B";
$entity2uni{"&boxuR;"}="2558";
$entity2uni{"&boxUl;"}="255C";
$entity2uni{"&boxdL;"}="2555";
$entity2uni{"&boxDr;"}="2553";
$entity2uni{"&boxUr;"}="2559";
$entity2uni{"&boxuL;"}="255B";
$entity2uni{"&boxDl;"}="2556";
$entity2uni{"&boxdR;"}="2552";

# Dclaration de la fonction de conversion des entits
# But :
# Environnement
# 	dclaration globale de %entity2uni avec ses donnes
# Entres : 
#	arg1 : string  convertir
#	arg2 : boolen xml. Si =1, on ne remplace pas &amp; &lt &gt
# Sorties :
#	valeur de retour : string convertie avec les car. correspondants

sub convertEntities {
	my $string=shift(@_); # lecture du premier argument dans la variable $string
	my $xml=shift(@_);
	my $result="";
	
	while ($string=~/^(.*?)(&#?\w+;)(.*)/s) {
		my $before= $1;
		my $entity= $2;
		my $after= $3;
		
		# on ajoute ce qui prcde
		$result.=$before; # $result=$result.$before;
		
		# conversion de l'entit p.ex. "&circ;"
		my $char=$entity;
		
		if ($entity !~/&(amp|lt|gt);/ || !$xml) {
			# 1/ on cherche la valeur unicode hexadcimale ou dcimale correspondante 
			if (exists($entity2uni{$entity})) {
				my $uni=$entity2uni{$entity}; # p.ex. "00EA"
				$char=chr(hex($uni)); # p.ex. ""
			} elsif ($entity=~/&#x([a-f\d]*);/i) {
				my $uni=$1; # p.ex. "00EA"
				$char=chr(hex($uni)); # p.ex. ""
			} elsif ($entity=~/&#(\d+);/) {
				$char=chr($1);
			}
		}
				
		# on ajoute le caractre converti
		$result.=$char;
		
		# on prpare la prochaine itration en rduisant $string  ce qui suit
		$string=$after;
		
	}
	# exemple de conversion $text =~s/&ecirc;/\N{U+00EA}/g;
	# on ajoute le reste  $result
	$result.=$string;
	
	return $result;
}


1;
